JSONEditor with forms

The form is set to send a `GET` request to the same page. A change event listener has been added to the editor so that whenever the form changes, the editor value is stored in a hidden input using `JSON.stringify()`.

The option `use_name_attributes` was set to `false` to avoid sending the other field with the request.

When the form is submitted only the hidden input is sent in the request. This allows to send data structures like arrays and object. Also the same schema that is used to build the form can be used as parameter to backend json validators tools. Try yourself, submit the form and look in the network tab of the developer tool.

## Get params